import os
import shutil
from utils import state, log
from const import *

def rm(item):
    type = state(item)
    match type:
        case "file": log(item, type, RM); os.remove(item)
        case "link": log(item, type, RM); os.unlink(item)
        case "dir": log(item, type, RM); os.rmdir(item)
        case "dirf": log(item, type, RM); shutil.rmtree(item)
        case _: return
    



from const import *
from os import path, listdir

def state(item):
    if path.isfile(item):
        return FILE
    elif path.isdir(item):
        if listdir(item) != None:
            return DIRF
        else:
            return DIR
    elif path.islink(item):
        return LINK

def log(item: str, type: str, action: bool):
    pass


def main():
    program = argparse.ArgumentParser(description="Transactional rm command, with power failure protocols")

    program.add_argument("-r", "--rm", help="Remove filesystem items", type=rm, nargs="+")
    program.add_argument("-b", "--rb", help="Rollback previously removed items", type=rollback, nargs="+")

    program.parse_args()

if __name__ == "__main__":
    import argparse
    from remove import rm
    from rollback import rollback
    main()


# type constants (file, links, empty directories, and directories with items)
FILE = "file"
DIR = "dir"
LINK = "link"
DIRF = "dirf"

# action constants (true for rollback, false for remove)
RM = False
RB = True


from setuptools import setup

with open("requirements.txt") as f:
    req = f.read().splitlines()

with open("README.md") as f:
    long_desc = f.read()

setup(
    name="transactional_remove",
    version="1.0.3",
    packages=["trm"],
    install_requires=req,
    entry_points={
        "console_scripts": [
            "trm=trm.trm:main",
        ],
    },
    long_description=long_desc,
    long_description_content_type="text/markdown"
)